pub enum DumpCommand {
    System {
        fields: Option<Vec<SystemOptionField>>,
        opts: GeneralOpt,
        pattern: Option<String>,
    },
    Disk {
        fields: Option<Vec<DiskOptionField>>,
        opts: GeneralOpt,
        select: Option<SingleDiskModelFieldId>,
        pattern: Option<String>,
    },
    Btrfs {
        fields: Option<Vec<BtrfsOptionField>>,
        opts: GeneralOpt,
        select: Option<BtrfsModelFieldId>,
        pattern: Option<String>,
    },
    Process {
        fields: Option<Vec<ProcessOptionField>>,
        opts: GeneralOpt,
        select: Option<SingleProcessModelFieldId>,
        pattern: Option<String>,
    },
    Cgroup {
        fields: Option<Vec<CgroupOptionField>>,
        opts: GeneralOpt,
        select: Option<SingleCgroupModelFieldId>,
        pattern: Option<String>,
    },
    Iface {
        fields: Option<Vec<IfaceOptionField>>,
        opts: GeneralOpt,
        select: Option<SingleNetModelFieldId>,
        pattern: Option<String>,
    },
    Network {
        fields: Option<Vec<NetworkOptionField>>,
        opts: GeneralOpt,
        pattern: Option<String>,
    },
    Transport {
        fields: Option<Vec<TransportOptionField>>,
        opts: GeneralOpt,
        pattern: Option<String>,
    },
}

Variants

System

Fields

fields: Option<Vec<SystemOptionField>>

Select which fields to display and in what order.

opts: GeneralOpt
pattern: Option<String>

Saved pattern in the dumprc file under [system] section.

Disk

Fields

fields: Option<Vec<DiskOptionField>>

Select which fields to display and in what order.

opts: GeneralOpt
select: Option<SingleDiskModelFieldId>

Select field for operation, use with –sort, –rsort, –filter, –top

pattern: Option<String>

Saved pattern in the dumprc file under [disk] section.

Btrfs

Fields

fields: Option<Vec<BtrfsOptionField>>

Select which fields to display and in what order.

opts: GeneralOpt
select: Option<BtrfsModelFieldId>

Select field for operation, use with –sort, –rsort, –filter, –top

pattern: Option<String>

Saved pattern in the dumprc file under [btrfs] section.

Process

Fields

fields: Option<Vec<ProcessOptionField>>

Select which fields to display and in what order.

opts: GeneralOpt
select: Option<SingleProcessModelFieldId>

Select field for operation, use with –sort, –rsort, –filter, –top

pattern: Option<String>

Saved pattern in the dumprc file under [process] section.

Cgroup

Fields

fields: Option<Vec<CgroupOptionField>>

Select which fields to display and in what order.

opts: GeneralOpt
select: Option<SingleCgroupModelFieldId>

Select field for operation, use with –sort, –rsort, –filter, –top

pattern: Option<String>

Saved pattern in the dumprc file under [cgroup] section.

Iface

Fields

fields: Option<Vec<IfaceOptionField>>

Select which fields to display and in what order.

opts: GeneralOpt
select: Option<SingleNetModelFieldId>

Select field for operation, use with –filter

pattern: Option<String>

Saved pattern in the dumprc file under [iface] section.

Network

Fields

fields: Option<Vec<NetworkOptionField>>

Select which fields to display and in what order.

opts: GeneralOpt
pattern: Option<String>

Saved pattern in the dumprc file under [network] section.

Transport

Fields

fields: Option<Vec<TransportOptionField>>

Select which fields to display and in what order.

opts: GeneralOpt
pattern: Option<String>

Saved pattern in the dumprc file under [transport] section.