Enum below_dump::command::DumpCommand
source · [−]pub enum DumpCommand {
System {
fields: Option<Vec<SystemOptionField>>,
opts: GeneralOpt,
pattern: Option<String>,
},
Disk {
fields: Option<Vec<DiskOptionField>>,
opts: GeneralOpt,
select: Option<SingleDiskModelFieldId>,
pattern: Option<String>,
},
Btrfs {
fields: Option<Vec<BtrfsOptionField>>,
opts: GeneralOpt,
select: Option<BtrfsModelFieldId>,
pattern: Option<String>,
},
Process {
fields: Option<Vec<ProcessOptionField>>,
opts: GeneralOpt,
select: Option<SingleProcessModelFieldId>,
pattern: Option<String>,
},
Cgroup {
fields: Option<Vec<CgroupOptionField>>,
opts: GeneralOpt,
select: Option<SingleCgroupModelFieldId>,
pattern: Option<String>,
},
Iface {
fields: Option<Vec<IfaceOptionField>>,
opts: GeneralOpt,
select: Option<SingleNetModelFieldId>,
pattern: Option<String>,
},
Network {
fields: Option<Vec<NetworkOptionField>>,
opts: GeneralOpt,
pattern: Option<String>,
},
Transport {
fields: Option<Vec<TransportOptionField>>,
opts: GeneralOpt,
pattern: Option<String>,
},
}Variants
System
Fields
fields: Option<Vec<SystemOptionField>>Select which fields to display and in what order.
opts: GeneralOptDisk
Fields
fields: Option<Vec<DiskOptionField>>Select which fields to display and in what order.
opts: GeneralOptselect: Option<SingleDiskModelFieldId>Select field for operation, use with –sort, –rsort, –filter, –top
Btrfs
Fields
fields: Option<Vec<BtrfsOptionField>>Select which fields to display and in what order.
opts: GeneralOptselect: Option<BtrfsModelFieldId>Select field for operation, use with –sort, –rsort, –filter, –top
Process
Fields
fields: Option<Vec<ProcessOptionField>>Select which fields to display and in what order.
opts: GeneralOptselect: Option<SingleProcessModelFieldId>Select field for operation, use with –sort, –rsort, –filter, –top
Cgroup
Fields
fields: Option<Vec<CgroupOptionField>>Select which fields to display and in what order.
opts: GeneralOptselect: Option<SingleCgroupModelFieldId>Select field for operation, use with –sort, –rsort, –filter, –top
Iface
Fields
fields: Option<Vec<IfaceOptionField>>Select which fields to display and in what order.
opts: GeneralOptselect: Option<SingleNetModelFieldId>Select field for operation, use with –filter
Network
Fields
fields: Option<Vec<NetworkOptionField>>Select which fields to display and in what order.
opts: GeneralOptTransport
Fields
fields: Option<Vec<TransportOptionField>>Select which fields to display and in what order.
opts: GeneralOptTrait Implementations
sourceimpl Clone for DumpCommand
impl Clone for DumpCommand
sourcefn clone(&self) -> DumpCommand
fn clone(&self) -> DumpCommand
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl CommandFactory for DumpCommand
impl CommandFactory for DumpCommand
sourcefn into_app_for_update<'b>() -> Command<'b>
fn into_app_for_update<'b>() -> Command<'b>
Deprecated, replaced with
CommandFactory::command_for_updatesourcefn command_for_update<'help>() -> App<'help>
fn command_for_update<'help>() -> App<'help>
sourceimpl Debug for DumpCommand
impl Debug for DumpCommand
sourceimpl FromArgMatches for DumpCommand
impl FromArgMatches for DumpCommand
sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches
) -> Result<Self, Error>
fn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches
) -> Result<Self, Error>
sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches
) -> Result<(), Error>
fn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches
) -> Result<(), Error>
Assign values from
ArgMatches to self.sourcefn update_from_arg_matches_mut<'b>(
&mut self,
__clap_arg_matches: &mut ArgMatches
) -> Result<(), Error>
fn update_from_arg_matches_mut<'b>(
&mut self,
__clap_arg_matches: &mut ArgMatches
) -> Result<(), Error>
Assign values from
ArgMatches to self.sourceimpl Parser for DumpCommand
impl Parser for DumpCommand
sourcefn parse_from<I, T>(itr: I) -> Selfwhere
I: IntoIterator<Item = T>,
T: Into<OsString> + Clone,
fn parse_from<I, T>(itr: I) -> Selfwhere
I: IntoIterator<Item = T>,
T: Into<OsString> + Clone,
Parse from iterator, exit on error
sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>where
I: IntoIterator<Item = T>,
T: Into<OsString> + Clone,
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>where
I: IntoIterator<Item = T>,
T: Into<OsString> + Clone,
Parse from iterator, return Err on error.
sourcefn update_from<I, T>(&mut self, itr: I)where
I: IntoIterator<Item = T>,
T: Into<OsString> + Clone,
fn update_from<I, T>(&mut self, itr: I)where
I: IntoIterator<Item = T>,
T: Into<OsString> + Clone,
Update from iterator, exit on error
sourcefn try_update_from<I, T>(&mut self, itr: I) -> Result<(), Error>where
I: IntoIterator<Item = T>,
T: Into<OsString> + Clone,
fn try_update_from<I, T>(&mut self, itr: I) -> Result<(), Error>where
I: IntoIterator<Item = T>,
T: Into<OsString> + Clone,
Update from iterator, return Err on error.
sourceimpl Subcommand for DumpCommand
impl Subcommand for DumpCommand
sourcefn augment_subcommands<'b>(__clap_app: Command<'b>) -> Command<'b>
fn augment_subcommands<'b>(__clap_app: Command<'b>) -> Command<'b>
sourcefn augment_subcommands_for_update<'b>(__clap_app: Command<'b>) -> Command<'b>
fn augment_subcommands_for_update<'b>(__clap_app: Command<'b>) -> Command<'b>
sourcefn has_subcommand(__clap_name: &str) -> bool
fn has_subcommand(__clap_name: &str) -> bool
Test whether
Self can parse a specific subcommandAuto Trait Implementations
impl RefUnwindSafe for DumpCommand
impl Send for DumpCommand
impl Sync for DumpCommand
impl Unpin for DumpCommand
impl UnwindSafe for DumpCommand