Enum below_dump::command::DumpCommand
source · [−]pub enum DumpCommand {
System {
fields: Option<Vec<SystemOptionField>>,
opts: GeneralOpt,
pattern: Option<String>,
},
Disk {
fields: Option<Vec<DiskOptionField>>,
opts: GeneralOpt,
select: Option<SingleDiskModelFieldId>,
pattern: Option<String>,
},
Process {
fields: Option<Vec<ProcessOptionField>>,
opts: GeneralOpt,
select: Option<SingleProcessModelFieldId>,
pattern: Option<String>,
},
Cgroup {
fields: Option<Vec<CgroupOptionField>>,
opts: GeneralOpt,
select: Option<SingleCgroupModelFieldId>,
pattern: Option<String>,
},
Iface {
fields: Option<Vec<IfaceOptionField>>,
opts: GeneralOpt,
select: Option<SingleNetModelFieldId>,
pattern: Option<String>,
},
Network {
fields: Option<Vec<NetworkOptionField>>,
opts: GeneralOpt,
pattern: Option<String>,
},
Transport {
fields: Option<Vec<TransportOptionField>>,
opts: GeneralOpt,
pattern: Option<String>,
},
}Variants
System
Fields
fields: Option<Vec<SystemOptionField>>Select which fields to display and in what order.
opts: GeneralOptDisk
Fields
fields: Option<Vec<DiskOptionField>>Select which fields to display and in what order.
opts: GeneralOptselect: Option<SingleDiskModelFieldId>Select field for operation, use with –sort, –rsort, –filter, –top
Process
Fields
fields: Option<Vec<ProcessOptionField>>Select which fields to display and in what order.
opts: GeneralOptselect: Option<SingleProcessModelFieldId>Select field for operation, use with –sort, –rsort, –filter, –top
Cgroup
Fields
fields: Option<Vec<CgroupOptionField>>Select which fields to display and in what order.
opts: GeneralOptselect: Option<SingleCgroupModelFieldId>Select field for operation, use with –sort, –rsort, –filter, –top
Iface
Fields
fields: Option<Vec<IfaceOptionField>>Select which fields to display and in what order.
opts: GeneralOptselect: Option<SingleNetModelFieldId>Select field for operation, use with –filter
Network
Fields
fields: Option<Vec<NetworkOptionField>>Select which fields to display and in what order.
opts: GeneralOptTransport
Fields
fields: Option<Vec<TransportOptionField>>Select which fields to display and in what order.
opts: GeneralOptTrait Implementations
Builds the struct from clap::ArgMatches. It’s guaranteed to succeed
if matches originates from an App generated by StructOpt::clap called on
the same type, otherwise it must panic. Read more
Builds the struct from the command line arguments (std::env::args_os).
Calls clap::Error::exit on failure, printing the error message and aborting the program. Read more
Builds the struct from the command line arguments (std::env::args_os).
Unlike StructOpt::from_args, returns clap::Error on failure instead of aborting the program,
so calling .exit is up to you. Read more
fn from_iter<I>(iter: I) -> Self where
I: IntoIterator,
<I as IntoIterator>::Item: Into<OsString>,
<I as IntoIterator>::Item: Clone,
fn from_iter<I>(iter: I) -> Self where
I: IntoIterator,
<I as IntoIterator>::Item: Into<OsString>,
<I as IntoIterator>::Item: Clone,
Gets the struct from any iterator such as a Vec of your making.
Print the error message and quit the program in case of failure. Read more
fn from_iter_safe<I>(iter: I) -> Result<Self, Error> where
I: IntoIterator,
<I as IntoIterator>::Item: Into<OsString>,
<I as IntoIterator>::Item: Clone,
fn from_iter_safe<I>(iter: I) -> Result<Self, Error> where
I: IntoIterator,
<I as IntoIterator>::Item: Into<OsString>,
<I as IntoIterator>::Item: Clone,
Gets the struct from any iterator such as a Vec of your making. Read more